score

package
v0.0.0-...-b04bc69 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 15, 2025 License: MIT Imports: 21 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterAllChecks

func RegisterAllChecks(
	allObjects ks.AllTypes,
	checksConfig *checks.Config,
	runConfig *config.RunConfiguration,
) *checks.Checks

func Score

func Score(
	allObjects ks.AllTypes,
	allChecks *checks.Checks,
	runConfig *config.RunConfiguration,
) (*scorecard.Scorecard, error)

Score runs a pre-configured list of tests against the files defined in the configuration, and returns a scorecard. Additional configuration and tuning parameters can be provided via the config.

Types

This section is empty.

Jump to