Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterAllChecks ¶
func Score ¶
func Score( allObjects ks.AllTypes, allChecks *checks.Checks, runConfig *config.RunConfiguration, ) (*scorecard.Scorecard, error)
Score runs a pre-configured list of tests against the files defined in the configuration, and returns a scorecard. Additional configuration and tuning parameters can be provided via the config.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.